"use strict";
/*
 * This program and the accompanying materials are made available under the terms of the
 * Eclipse Public License v2.0 which accompanies this distribution, and is available at
 * https://www.eclipse.org/legal/epl-v20.html
 *
 * SPDX-License-Identifier: EPL-2.0
 *
 * Copyright Contributors to the Zowe Project.
 */
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const imperative_1 = require("@zowe/imperative");
const path = require("path");
class UpdateAllHandler {
    process(params) {
        return __awaiter(this, void 0, void 0, function* () {
            // Boolean to check if user has profiles or not
            let noProfiles = true;
            // profiles folder
            const profilesRootDir = imperative_1.ProfileUtils.constructProfilesRootDirectory(imperative_1.ImperativeConfig.instance.cliHome);
            const listOfProfileTypes = imperative_1.ProfileIO.getAllProfileDirectories(profilesRootDir);
            for (const profileType of listOfProfileTypes) {
                // Generic profile configuration
                const profileConfig = { profileRootDirectory: profilesRootDir, type: profileType };
                // Base directory for the given type of profile
                const profileTypeDir = path.join(profilesRootDir, profileType);
                // Names of the profiles of this type
                const profileNames = yield imperative_1.ProfileIO.getAllProfileNames(profileTypeDir, ".yaml", `${profileType}_meta`);
                // Profile type meta file
                const profileMetaFile = imperative_1.ProfileIO.readMetaFile(path.join(profileTypeDir, `${profileType}_meta.yaml`));
                // Check to see if there are no profiles to be updated
                if (profileNames.length > 0) {
                    noProfiles = false;
                }
                for (const profileName of profileNames) {
                    const profile = imperative_1.ProfileIO.readProfileFile(path.join(profileTypeDir, `${profileName}.yaml`), profileType);
                    try {
                        // Indicator of whether a profile is already secured
                        let alreadySecured = false;
                        for (const profileProperty in profile) {
                            // Does this property start with the words 'managed by'?
                            if (profile[profileProperty].toString().indexOf(imperative_1.ProfilesConstants.PROFILES_OPTION_SECURELY_STORED) === 0) {
                                // If so, Is this property secure?
                                if (profileMetaFile.configuration.schema.properties[profileProperty].secure) {
                                    alreadySecured = true;
                                }
                            }
                        }
                        if (alreadySecured) {
                            // Do not overwrite a profile seems to be already secured
                            params.response.console.log(`Profile ("${profileName} of type "${profileType}") was already secured`);
                        }
                        else {
                            // Overwrite this plain text profiles
                            const res = yield new imperative_1.CliProfileManager(profileConfig).save({
                                name: profileName,
                                type: profileType,
                                profile,
                                updateDefault: false,
                                overwrite: true
                            });
                            params.response.console.log(res.message);
                        }
                    }
                    catch (err) {
                        params.response.console.errorHeader("Error");
                        params.response.console.error(err.message);
                    }
                }
            }
            if (noProfiles) {
                params.response.console.log("There are no profiles to update");
            }
        });
    }
}
exports.default = UpdateAllHandler;
//# sourceMappingURL=UpdateAll.handler.js.map